# Vetur Terminal Interface

🚧 WIP. This feature is not stable yet. 🚧

VTI is a CLI that exposes some of Vetur's language features:

- [x] Diagnostic errors
- [ ] Formatting

## Usage

```bash
npm i -g vti
# or yarn global add vti
# In your Vue project root
vti diagnostics
```
